import os
import stat

from django.template import Library
from django.conf import settings

register = Library()


@register.filter(name='is_format_available')
def is_available(soundfile, format='ogg'):
    if soundfile is None:
        return False
    sound_path = soundfile.get_format_path(format)
    if not sound_path:
        return False
    if settings.DEBUG is False:
        return True
    return os.path.exists(sound_path)

@register.filter(name='format_url')
def format_url(soundfile, format='ogg'):
    return soundfile.get_format_url(format)

@register.filter
def format_length(soundfile, format='ogg'):
    if not is_available(soundfile, format):
        return 0
    sound_path = soundfile.get_format_path(format)
    return os.stat(sound_path)[stat.ST_SIZE]

@register.filter
def sound_filename(soundfile):
    return soundfile.file.name.split('/')[-1]
